@@ -8,10 +8,10 @@ import math
 import re
 import sys
 import time
-from typing import Tuple, Union, Optional, Any, Type, List, Callable, Sequence, Dict, Set
+from typing import Iterable, Tuple, Union, Optional, Any, Type, List, Callable, Sequence, Dict, Set
 
 from . import _msgs as msgs
-from ._helpers import null_terminate, SimpleError, Database
+from ._helpers import null_terminate, SimpleError, Database, current_time
 
 MAX_STRING_SIZE = 512 * 1024 * 1024
 SUPPORTED_COMMANDS: Dict[str, "Signature"] = dict()  # Dictionary of supported commands name => Signature
@@ -45,7 +45,7 @@ class CommandItem:
     """
 
     def __init__(self, key: bytes, db: Database, item: Optional["CommandItem"] = None, default: Any = None) -> None:
-        self._expireat: Optional[int]
+        self._expireat: Optional[float]
         if item is None:
             self._value = default
             self._expireat = None
@@ -68,11 +68,11 @@ class CommandItem:
         self.expireat = None
 
     @property
-    def expireat(self) -> Optional[int]:
+    def expireat(self) -> Optional[float]:
         return self._expireat
 
     @expireat.setter
-    def expireat(self, value: Optional[int]) -> None:
+    def expireat(self, value: Optional[float]) -> None:
         self._expireat = value
         self._expireat_modified = True
         self._modified = True  # Since redis 6.0.7
@@ -107,10 +107,81 @@ class CommandItem:
     __nonzero__ = __bool__  # For Python 2
 
 
-class Hash(dict):  # type:ignore
+class Hash:  # type:ignore
     DECODE_ERROR = msgs.INVALID_HASH_MSG
     redis_type = b"hash"
 
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        super().__init__(*args, **kwargs)
+        self._expirations: Dict[bytes, int] = dict()
+        self._values: Dict[bytes, Any] = dict()
+
+    def _expire_keys(self):
+        removed = []
+        now = current_time()
+        for k in self._expirations:
+            if self._expirations[k] < now:
+                self._values.pop(k, None)
+                removed.append(k)
+        for k in removed:
+            self._expirations.pop(k, None)
+
+    def set_key_expireat(self, key: bytes, when_ms: int) -> int:
+        now = current_time()
+        if when_ms <= now:
+            self._values.pop(key, None)
+            self._expirations.pop(key, None)
+            return 2
+        self._expirations[key] = when_ms
+        return 1
+
+    def clear_key_expireat(self, key: bytes) -> bool:
+        return self._expirations.pop(key, None) is not None
+
+    def get_key_expireat(self, key: bytes) -> Optional[int]:
+        self._expire_keys()
+        return self._expirations.get(key, None)
+
+    def __getitem__(self, key: bytes) -> Any:
+        self._expire_keys()
+        return self._values.get(key)
+
+    def __contains__(self, key: bytes) -> bool:
+        self._expire_keys()
+        return self._values.__contains__(key)
+
+    def __setitem__(self, key: bytes, value: Any) -> None:
+        self._expirations.pop(key, None)
+        self._values[key] = value
+
+    def __delitem__(self, key):
+        self._values.pop(key, None)
+        self._expirations.pop(key, None)
+
+    def __len__(self):
+        return len(self._values)
+
+    def __iter__(self):
+        return iter(self._values)
+
+    def get(self, key: bytes, default: Any = None) -> Any:
+        return self._values.get(key, default)
+
+    def keys(self) -> Iterable[bytes]:
+        self._expire_keys()
+        return self._values.keys()
+
+    def values(self) -> Iterable[Any]:
+        return [v for k, v in self.items()]
+
+    def items(self) -> Iterable[Tuple[bytes, Any]]:
+        self._expire_keys()
+        return self._values.items()
+
+    def update(self, values: Dict[bytes, Any]) -> None:
+        self._expire_keys()
+        self._values.update(values)
+
 
 class RedisType:
     @classmethod
